@@ -29,8 +29,6 @@
 #include <QtCore/qobject.h>
 #include <QtScript/qtscriptglobal.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -48,6 +46,4 @@ Q_DECLARE_INTERFACE(QScriptExtensionInterface, QScriptExtensionInterface_iid)
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif // QSCRIPTEXTENSIONINTERFACE_H
