@@ -30,8 +30,6 @@
 #include <QtCore/qsharedpointer.h>
 #include <QtScript/qtscriptglobal.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 
@@ -218,6 +216,4 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(QScriptValue::PropertyFlags)
 
 QT_END_NAMESPACE
 
-QT_END_HEADER
-
 #endif
